@@ -141,6 +141,8 @@ class Welcome:
 
         if (ft == 'json'):
             return json.dumps(od)
+        elif ft=='list':
+            return [{x:d.get(x,'NONE')} for x in sorted(d)]
         elif (ft == 'html'):
             return json2html.convert(json = json.dumps(od))
             
@@ -278,4 +280,6 @@ class Welcome:
 
 if __name__ == '__main__':
 
-    print(Welcome.get_fetchdata())
\ No newline at end of file
+    print(Welcome.get_all_libs('list'))
+
+
